// src/codemods/helpers/update-source-value.ts
import path from "path";
function getUpdatedSourceValue(sourceValue, transformFn) {
  const transformed = transformPath(sourceValue, transformFn);
  if (transformed !== sourceValue) {
    return transformed;
  }
  return null;
}
var targetPathPrefixes = ["./", "../", "~/", "@/", "@src/", "#"];
function transformPath(filePath, casingFn) {
  const prefix = targetPathPrefixes.find((p) => filePath.startsWith(p));
  if (!prefix) {
    return filePath;
  }
  const pathWithoutPrefix = filePath.slice(prefix.length);
  const segments = pathWithoutPrefix.split(path.sep);
  const newSegments = segments.map((segment, index) => {
    if (index === segments.length - 1) {
      return convertFileName(segment, casingFn);
    }
    return convertSegment(segment, casingFn);
  });
  const newPath = prefix + newSegments.join(path.sep);
  return newPath;
}
function convertFileName(fileName, casingFn) {
  const ext = path.extname(fileName);
  const baseName = path.basename(fileName, ext);
  const convertedBaseName = convertSegment(baseName, casingFn);
  return convertedBaseName + ext;
}
function convertSegment(segment, casingFn) {
  if (segment.startsWith("[")) {
    return segment;
  }
  return casingFn(segment);
}

// src/codemods/helpers/update-imports-and-exports.ts
function updateImportsAndExports(j, root, casingFn) {
  root.find(j.ImportDeclaration).forEach((path2) => {
    const newValue = getUpdatedSourceValue(
      path2.node.source.value,
      casingFn
    );
    if (newValue) path2.node.source.value = newValue;
  });
  root.find(j.ExportNamedDeclaration).forEach((path2) => {
    if (path2.node.source) {
      const newValue = getUpdatedSourceValue(
        path2.node.source.value,
        casingFn
      );
      if (newValue) path2.node.source.value = newValue;
    }
  });
  root.find(j.ExportAllDeclaration).forEach((path2) => {
    if (path2.node.source) {
      const newValue = getUpdatedSourceValue(
        path2.node.source.value,
        casingFn
      );
      if (newValue) path2.node.source.value = newValue;
    }
  });
  root.find(j.TSImportType).forEach((path2) => {
    const newValue = getUpdatedSourceValue(
      path2.node.argument.value,
      casingFn
    );
    if (newValue) path2.node.argument.value = newValue;
  });
  root.find(j.CallExpression, { callee: { name: "require" } }).forEach((path2) => {
    const arg = path2.node.arguments[0];
    if (arg.type === "StringLiteral" && typeof arg.value === "string") {
      const newValue = getUpdatedSourceValue(arg.value, casingFn);
      if (newValue)
        path2.node.arguments[0].value = newValue;
    }
  });
  root.find(j.ImportExpression).forEach((path2) => {
    console.log(
      "Found import expression",
      path2.node.source,
      path2.node.source.value
    );
    const newValue = getUpdatedSourceValue(
      path2.node.source.value,
      casingFn
    );
    if (newValue) path2.node.source.value = newValue;
  });
  return root.toSource();
}

export {
  updateImportsAndExports
};
