"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/codemods/convert-import-export-snake.ts
var convert_import_export_snake_exports = {};
__export(convert_import_export_snake_exports, {
  default: () => transformer
});
module.exports = __toCommonJS(convert_import_export_snake_exports);

// src/lib/get-casing-function.ts
function kebabCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1-$2").replace(/[\s_]+/g, "-").toLowerCase();
}
function snakeCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1_$2").replace(/[\s-]+/g, "_").toLowerCase();
}
function getCasingFunction(casing) {
  return casing === "kebab" ? kebabCase : snakeCase;
}

// src/codemods/helpers/update-source-value.ts
var import_path = __toESM(require("path"), 1);
function getUpdatedSourceValue(sourceValue, transformFn) {
  const transformed = transformPath(sourceValue, transformFn);
  if (transformed !== sourceValue) {
    return transformed;
  }
  return null;
}
var targetPathPrefixes = ["./", "../", "~/", "@/", "@src/", "#"];
function transformPath(filePath, casingFn2) {
  const prefix = targetPathPrefixes.find((p) => filePath.startsWith(p));
  if (!prefix) {
    return filePath;
  }
  const pathWithoutPrefix = filePath.slice(prefix.length);
  const segments = pathWithoutPrefix.split(import_path.default.sep);
  const newSegments = segments.map((segment, index) => {
    if (index === segments.length - 1) {
      return convertFileName(segment, casingFn2);
    }
    return convertSegment(segment, casingFn2);
  });
  const newPath = prefix + newSegments.join(import_path.default.sep);
  return newPath;
}
function convertFileName(fileName, casingFn2) {
  const ext = import_path.default.extname(fileName);
  const baseName = import_path.default.basename(fileName, ext);
  const convertedBaseName = convertSegment(baseName, casingFn2);
  return convertedBaseName + ext;
}
function convertSegment(segment, casingFn2) {
  if (segment.startsWith("[")) {
    return segment;
  }
  return casingFn2(segment);
}

// src/codemods/helpers/update-imports-and-exports.ts
function updateImportsAndExports(j, root, casingFn2) {
  root.find(j.ImportDeclaration).forEach((path2) => {
    const newValue = getUpdatedSourceValue(
      path2.node.source.value,
      casingFn2
    );
    if (newValue) path2.node.source.value = newValue;
  });
  root.find(j.ExportNamedDeclaration).forEach((path2) => {
    if (path2.node.source) {
      const newValue = getUpdatedSourceValue(
        path2.node.source.value,
        casingFn2
      );
      if (newValue) path2.node.source.value = newValue;
    }
  });
  root.find(j.ExportAllDeclaration).forEach((path2) => {
    if (path2.node.source) {
      const newValue = getUpdatedSourceValue(
        path2.node.source.value,
        casingFn2
      );
      if (newValue) path2.node.source.value = newValue;
    }
  });
  root.find(j.TSImportType).forEach((path2) => {
    const newValue = getUpdatedSourceValue(
      path2.node.argument.value,
      casingFn2
    );
    if (newValue) path2.node.argument.value = newValue;
  });
  root.find(j.CallExpression, { callee: { name: "require" } }).forEach((path2) => {
    const arg = path2.node.arguments[0];
    if (arg.type === "StringLiteral" && typeof arg.value === "string") {
      const newValue = getUpdatedSourceValue(arg.value, casingFn2);
      if (newValue)
        path2.node.arguments[0].value = newValue;
    }
  });
  root.find(j.ImportExpression).forEach((path2) => {
    console.log(
      "Found import expression",
      path2.node.source,
      path2.node.source.value
    );
    const newValue = getUpdatedSourceValue(
      path2.node.source.value,
      casingFn2
    );
    if (newValue) path2.node.source.value = newValue;
  });
  return root.toSource();
}

// src/codemods/convert-import-export-snake.ts
var casingFn = getCasingFunction("snake");
function transformer(fileInfo, api) {
  const j = api.jscodeshift;
  const root = j(fileInfo.source);
  return updateImportsAndExports(j, root, casingFn);
}
